@@ -32,6 +32,7 @@
 #include <regex>
 #include <glib/gstdio.h> // to get stats
 #include <curl/curl.h>
+#include <uchardet.h>
 #include <spdlog/fmt/bundled/printf.h>
 
 #include <thread> // for parallel_for
@@ -540,12 +541,22 @@ guint32 CtStrUtil::guint32_from_hex_chars(const char* hexChars, guint8 numChars)
     return (guint32)strtoul(hexstring, nullptr, 16);
 }
 
+std::vector<int> CtStrUtil::gstring_split_to_int(const gchar* inStr, const gchar* delimiter, gint max_tokens)
+{
+    std::vector<int> retVec;
+    gchar** arrayOfStrings = g_strsplit(inStr, delimiter, max_tokens);
+    for (gchar** ptr = arrayOfStrings; *ptr; ptr++) {
+        int curr_int = gint64_from_gstring(*ptr);
+        retVec.push_back(curr_int);
+    }
+    g_strfreev(arrayOfStrings);
+    return retVec;
+}
 std::vector<gint64> CtStrUtil::gstring_split_to_int64(const gchar* inStr, const gchar* delimiter, gint max_tokens)
 {
     std::vector<gint64> retVec;
     gchar** arrayOfStrings = g_strsplit(inStr, delimiter, max_tokens);
-    for (gchar** ptr = arrayOfStrings; *ptr; ptr++)
-    {
+    for (gchar** ptr = arrayOfStrings; *ptr; ptr++) {
         gint64 curr_int = gint64_from_gstring(*ptr);
         retVec.push_back(curr_int);
     }
@@ -665,6 +676,51 @@ std::string CtStrUtil::get_internal_link_from_http_url(std::string link_url)
     else                                            return "webs http://" + link_url;
 }
 
+std::string CtStrUtil::get_encoding(const char* const pData, const size_t dataLen)
+{
+    std::string retStr;
+    uchardet_t handle = uchardet_new();
+    if (0 == uchardet_handle_data(handle, pData, dataLen)) {
+        uchardet_data_end(handle);
+        retStr = uchardet_get_charset(handle);
+    }
+    uchardet_delete(handle);
+    return retStr;
+}
+
+void CtStrUtil::convert_from_bom(Glib::ustring& text)
+{
+    const std::string codeset = CtStrUtil::get_encoding(text.c_str(), text.size());
+    if (codeset != "" && codeset != "ASCII" && codeset != "UTF-8")
+        text = Glib::convert_with_fallback(text, "UTF-8", codeset);
+
+    /*
+    const char* sbuf = text.c_str();
+    int slen = text.bytes();
+    const char* charset = nullptr;
+    if (slen>=4 && memcmp(sbuf, "\x84\x31\x95\x33", 4)==0)
+        charset = "GB-18030";
+    else if (slen>=4 && memcmp(sbuf, "\x00\x00\xFE\xFF", 4)==0)
+        charset = "UTF-32BE";
+    else if (slen>=4 && memcmp(sbuf, "\xFF\xFE\x00\x00", 4)==0)
+        charset = "UTF-32LE";
+    else if (slen>=2 && memcmp(sbuf, "\xFE\xFF", 2)==0)
+        charset = "UTF-16BE";
+    else if (slen>=2 && memcmp(sbuf, "\xFF\xFE", 2)==0)
+        charset = "UTF-16LE";
+
+    if (charset)
+    {
+        gsize bytes_written = 0;
+        if (gchar* converted_text = g_convert(sbuf, slen, "UTF-8", charset, 0, &bytes_written, nullptr))
+        {
+            text = converted_text;
+            g_free(converted_text);
+        }
+    }
+    */
+}
+
 Glib::ustring CtFontUtil::get_font_family(const Glib::ustring& fontStr)
 {
     return Pango::FontDescription(fontStr).get_family();
