@@ -99,7 +99,13 @@ CtAnchoredWidget::CtAnchoredWidget(CtMainWin* pCtMainWin, const int charOffset,
    _justification(justification)
 {
     _frame.set_shadow_type(Gtk::ShadowType::SHADOW_NONE);
-    signal_button_press_event().connect([](GdkEventButton* /*pEvent*/){ return true; });
+    signal_button_press_event().connect([this](GdkEventButton* /*pEvent*/){
+        _pCtMainWin->curr_buffer()->place_cursor(_pCtMainWin->curr_buffer()->get_iter_at_child_anchor((_rTextChildAnchor)));
+        if (not _pCtMainWin->curr_buffer()->get_modified()) {
+            _pCtMainWin->get_state_machine().update_curr_state_cursor_pos(_pCtMainWin->curr_tree_iter().get_node_id());
+        }
+        return true; // we need to block this or the focus will go to the text buffer below
+    });
     add(_frame);
 }
 
@@ -134,10 +140,14 @@ CtTreeView::~CtTreeView()
 {
 }
 
-void CtTreeView::set_cursor_safe(const Gtk::TreeIter& iter)
+void CtTreeView::set_cursor_safe(const Gtk::TreeIter& treeIter)
 {
-    expand_to_path(get_model()->get_path(iter));
-    set_cursor(get_model()->get_path(iter));
+    Gtk::TreeRow row = *treeIter;
+    Gtk::TreeIter iterParent = row.parent();
+    if (iterParent) {
+        expand_to_path(get_model()->get_path(iterParent));
+    }
+    set_cursor(get_model()->get_path(treeIter));
 }
 
 void CtTreeView::set_tree_node_name_wrap_width(const bool wrap_enabled, const int wrap_width)
@@ -231,18 +241,22 @@ void CtTextView::setup_for_syntax(const std::string& syntax)
          CtConst::TABLE_CELL_TEXT_ID == syntax )
     {
         set_highlight_current_line(_pCtMainWin->get_ct_config()->rtHighlCurrLine);
-        if (_pCtMainWin->get_ct_config()->rtShowWhiteSpaces)
-        {
+        if (_pCtMainWin->get_ct_config()->rtShowWhiteSpaces) {
             set_draw_spaces(Gsv::DRAW_SPACES_ALL & ~Gsv::DRAW_SPACES_NEWLINE);
         }
+        else {
+            set_draw_spaces(static_cast<Gsv::DrawSpacesFlags>(0));
+        }
     }
     else
     {
         set_highlight_current_line(_pCtMainWin->get_ct_config()->ptHighlCurrLine);
-        if (_pCtMainWin->get_ct_config()->ptShowWhiteSpaces)
-        {
+        if (_pCtMainWin->get_ct_config()->ptShowWhiteSpaces) {
             set_draw_spaces(Gsv::DRAW_SPACES_ALL & ~Gsv::DRAW_SPACES_NEWLINE);
         }
+        else {
+            set_draw_spaces(static_cast<Gsv::DrawSpacesFlags>(0));
+        }
     }
 }
 
@@ -538,18 +552,24 @@ void CtTextView::for_event_after_key_press(GdkEvent* event, const Glib::ustring&
             int chars_to_startoffs = 1 + CtList(_pCtMainWin, text_buffer).get_leading_chars_num(list_info.type, list_info.num) + 3*list_info.level;
             if ((insert_offset - list_info.startoffs) == chars_to_startoffs)
             {
-                Gtk::TextIter iter_list_quit;
-                // enter on empty list element
-                if (list_info.level > 0)
-                {
-                    list_change_level(iter_insert, list_info, false);
-                    iter_insert = text_buffer->get_insert()->get_iter();
-                    iter_list_quit = text_buffer->get_iter_at_offset(iter_insert.get_offset()-1);
+                if (iter_insert.ends_line()) {
+                    // enter on empty list element
+                    Gtk::TextIter iter_list_quit;
+                    if (list_info.level > 0)
+                    {
+                        list_change_level(iter_insert, list_info, false);
+                        iter_insert = text_buffer->get_insert()->get_iter();
+                        iter_list_quit = text_buffer->get_iter_at_offset(iter_insert.get_offset()-1);
+                    }
+                    else
+                        iter_list_quit = text_buffer->get_iter_at_offset(list_info.startoffs);
+                    text_buffer->erase(iter_list_quit, iter_insert);
+                    return;
                 }
-                else
-                    iter_list_quit = text_buffer->get_iter_at_offset(list_info.startoffs);
-                text_buffer->erase(iter_list_quit, iter_insert);
-                return;
+                // the list element was not empty, this list element should get a new list prefix
+                iter_start = iter_insert;
+                (void)iter_start.backward_chars(2);
+                list_info = CtList(_pCtMainWin, text_buffer).get_paragraph_list_info(iter_start);
             }
             // list new element
             int curr_level = list_info.level;
@@ -577,7 +597,7 @@ void CtTextView::for_event_after_key_press(GdkEvent* event, const Glib::ustring&
                     Gtk::TextIter iter_end = text_buffer->get_iter_at_offset(end_offset);
                     CtTextRange range = CtList(_pCtMainWin, text_buffer).list_check_n_remove_old_list_type_leading(iter_start, iter_end);
                     end_offset -= range.leading_chars_num;
-                    text_buffer->insert(iter_start, std::to_string(new_num) + Glib::ustring(1, CtConst::CHARS_LISTNUM[(size_t)index]) + CtConst::CHAR_SPACE);
+                    text_buffer->insert(range.iter_start, std::to_string(new_num) + Glib::ustring(1, CtConst::CHARS_LISTNUM[(size_t)index]) + CtConst::CHAR_SPACE);
                     end_offset += CtList(_pCtMainWin, text_buffer).get_leading_chars_num(list_info.type, new_num);
                     iter_start = text_buffer->get_iter_at_offset(end_offset);
                     new_num += 1;
@@ -752,8 +772,21 @@ void CtTextView::zoom_text(const bool is_increase, const std::string& syntaxHigh
     if (size < 6) size = 6;
     fontDesc.set_size(size * Pango::SCALE);
     override_font(fontDesc);
+
     if (syntaxHighlighting == CtConst::RICH_TEXT_ID) {
         _pCtMainWin->get_ct_config()->rtFont = CtFontUtil::get_font_str(fontDesc);
+        // also fix monospace font size
+        if (not _pCtMainWin->get_ct_config()->monospaceFont.empty())
+        {
+            Pango::FontDescription monoFontDesc(_pCtMainWin->get_ct_config()->monospaceFont);
+            int monoSize = monoFontDesc.get_size() / Pango::SCALE + (is_increase ? 1 : -1);
+            if (monoSize < 6) monoSize = 6;
+            monoFontDesc.set_size(monoSize * Pango::SCALE);
+
+            _pCtMainWin->get_ct_config()->monospaceFont = CtFontUtil::get_font_str(monoFontDesc);
+            if (auto tag = get_buffer()->get_tag_table()->lookup(CtConst::TAG_FAMILY + Glib::ustring("_") + CtConst::TAG_PROP_VAL_MONOSPACE))
+                tag->property_font() = _pCtMainWin->get_ct_config()->monospaceFont;
+        }
     }
     else if (syntaxHighlighting == CtConst::PLAIN_TEXT_ID) {
         _pCtMainWin->get_ct_config()->ptFont = CtFontUtil::get_font_str(fontDesc);
